cosmpy.protos.cosmos.crisis.v1beta1 package — cosmpy documentation

# cosmpy.protos.cosmos.crisis.v1beta1 package

## Submodules

## cosmpy.protos.cosmos.crisis.v1beta1.genesis_pb2 module

Generated protocol buffer code.

## cosmpy.protos.cosmos.crisis.v1beta1.genesis_pb2_grpc module

Client and server classes corresponding to protobuf-defined services.

## cosmpy.protos.cosmos.crisis.v1beta1.tx_pb2 module

Generated protocol buffer code.

## cosmpy.protos.cosmos.crisis.v1beta1.tx_pb2_grpc module

Client and server classes corresponding to protobuf-defined services.

class cosmpy.protos.cosmos.crisis.v1beta1.tx_pb2_grpc.Msg

  Bases: `object`

  Msg defines the bank Msg service.

  static VerifyInvariant(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)

class cosmpy.protos.cosmos.crisis.v1beta1.tx_pb2_grpc.MsgServicer

  Bases: `object`

  Msg defines the bank Msg service.

  VerifyInvariant(request, context)

    VerifyInvariant defines a method to verify a particular invariance.

class cosmpy.protos.cosmos.crisis.v1beta1.tx_pb2_grpc.MsgStub(channel)

  Bases: `object`

  Msg defines the bank Msg service.

cosmpy.protos.cosmos.crisis.v1beta1.tx_pb2_grpc.add_MsgServicer_to_server(servicer, server)

## Module contents